@@ -149,8 +149,10 @@ setMethod(
     #Create function to calculate RMSE
     calc.RMSE <- function(x, reps){ 
       true.x <- x[(reps+1)]
-      x <- x[1:reps]
-      return( sqrt( sum((x-true.x)^2) / reps ))
+      x <- na.omit(x[1:reps])
+      reps.success <- length(x)
+      return( sqrt( sum((x-true.x)^2) / reps.success ))
+      #Probably should warn is reps.success does not equal number of times the simulation succeeded.
     }
     #Get number of reps
     reps <- object@reps
