@@ -1,6 +1,6 @@
-hn.detect <- function(perp.dists, detectability){
+hn.detect <- function(dists, detectability){
 #returns the probability of detection based on a half-normal detection function
-  x <- perp.dists
+  x <- dists
   if(length(detectability@scale.param) > 1){
     sig <- sample(detectability@scale.param, length(x), replace = TRUE)
   }else{
